(*
    This file is part of the CompatibilityLayer project -
    which gives various ML compilers a more uniform set of
    Standard ML Basis library modules.
    
    Copyright (C) 2000 ANOQ of the Sun (alias Johnny Andersen).
    
    E-mail: anoq@HardcoreProcessing.com

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    As a special exception, if you do not do anything which is not in
    the spirit of the GNU Library General Public License, you are not
    required to physically compile this software into a separate library,
    since this is generally not possible with current Stanard ML compilers.
    However if you do something which is not in the spirit of the
    GNU Library General Public License you will have to follow the
    licence perpetually - thus disallowing you to use it for any
    commercial purposes at all.

    If you are interested in a warranty or commercial support for this
    software, contact Hardcore Processing <sales@HardcoreProcessing.com>
    for more information.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*)

(* This structure is not in SML/NJ, so it will be emulated... *)
structure IntVector : MONO_VECTOR =
  struct
    type vector = int Vector.vector
    type elem = int
    val maxLen = Vector.maxLen 
    val fromList = Vector.fromList 
    val tabulate = Vector.tabulate 
    val length = Vector.length 
    val sub = Vector.sub
    val extract = Vector.extract 
    val concat = Vector.concat 
    val mapi = Vector.mapi 
    val map = Vector.map 
    val appi = Vector.appi 
    val app = Vector.app
    val foldli = Vector.foldli
    val foldri = Vector.foldri
    val foldl = Vector.foldl 
    val foldr = Vector.foldr
  end

(* This structure is not in SML/NJ, so it will be emulated... *)
structure StringVector : MONO_VECTOR =
  struct
    type vector = string Vector.vector
    type elem = string
    val maxLen = Vector.maxLen 
    val fromList = Vector.fromList 
    val tabulate = Vector.tabulate 
    val length = Vector.length 
    val sub = Vector.sub
    val extract = Vector.extract 
    val concat = Vector.concat 
    val mapi = Vector.mapi 
    val map = Vector.map 
    val appi = Vector.appi 
    val app = Vector.app
    val foldli = Vector.foldli
    val foldri = Vector.foldri
    val foldl = Vector.foldl 
    val foldr = Vector.foldr
  end

(* This structure is not in SML/NJ, so it will be emulated... *)
structure BoolVector : MONO_VECTOR =
  struct
    type vector = bool Vector.vector
    type elem = bool
    val maxLen = Vector.maxLen 
    val fromList = Vector.fromList 
    val tabulate = Vector.tabulate 
    val length = Vector.length 
    val sub = Vector.sub
    val extract = Vector.extract 
    val concat = Vector.concat 
    val mapi = Vector.mapi 
    val map = Vector.map 
    val appi = Vector.appi 
    val app = Vector.app
    val foldli = Vector.foldli
    val foldri = Vector.foldri
    val foldl = Vector.foldl 
    val foldr = Vector.foldr
  end

(* This structure is not in SML/NJ, so it will be emulated... *)
structure IntArray : MONO_ARRAY =
  struct
    type array = int Array.array
    type elem = int
    structure Vector = IntVector
    type vector = Vector.vector
    val array = Array.array
    val maxLen = Array.maxLen 
    val fromList = Array.fromList 
    val tabulate = Array.tabulate 
    val length = Array.length 
    val sub = Array.sub
    val update = Array.update
    val extract = Array.extract
    val copy = Array.copy
    val copyVec = Array.copyVec
    val appi = Array.appi 
    val app = Array.app
    val foldli = Array.foldli
    val foldri = Array.foldri
    val foldl = Array.foldl 
    val foldr = Array.foldr
    val modifyi = Array.modifyi 
    val modify = Array.modify
  end

(* This structure is not in SML/NJ, so it will be emulated... *)
structure StringArray : MONO_ARRAY =
  struct
    type array = string Array.array
    type elem = string
    structure Vector = StringVector
    type vector = Vector.vector
    val array = Array.array
    val maxLen = Array.maxLen 
    val fromList = Array.fromList 
    val tabulate = Array.tabulate 
    val length = Array.length 
    val sub = Array.sub
    val update = Array.update
    val extract = Array.extract
    val copy = Array.copy
    val copyVec = Array.copyVec
    val appi = Array.appi 
    val app = Array.app
    val foldli = Array.foldli
    val foldri = Array.foldri
    val foldl = Array.foldl 
    val foldr = Array.foldr
    val modifyi = Array.modifyi 
    val modify = Array.modify
  end

(* This structure is not in SML/NJ, so it will be emulated... *)
structure BoolArray : MONO_ARRAY =
  struct
    type array = bool Array.array
    type elem = bool
    structure Vector = BoolVector
    type vector = Vector.vector
    val array = Array.array
    val maxLen = Array.maxLen 
    val fromList = Array.fromList 
    val tabulate = Array.tabulate 
    val length = Array.length 
    val sub = Array.sub
    val update = Array.update
    val extract = Array.extract
    val copy = Array.copy
    val copyVec = Array.copyVec
    val appi = Array.appi 
    val app = Array.app
    val foldli = Array.foldli
    val foldri = Array.foldri
    val foldl = Array.foldl 
    val foldr = Array.foldr
    val modifyi = Array.modifyi 
    val modify = Array.modify
  end